var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};

// src/util/index.ts
var util_exports = {};
__export(util_exports, {
  createDate: () => createDate,
  createDateFromNowWithOffset: () => createDateFromNowWithOffset,
  downloadFileFromUrl: () => downloadFileFromUrl,
  fsDeleteDirectory: () => fsDeleteDirectory,
  fsDeleteFile: () => fsDeleteFile,
  fsReadJSONFile: () => readJSONFile,
  fsWriteJsonToFile: () => writeJsonToFile,
  fsWriteToFile: () => writeToFile
});

// src/util/dateTime.ts
var createDate = (hours, minutes) => {
  const date = /* @__PURE__ */ new Date();
  date.setHours(hours, minutes, 0, 0);
  return date;
};
var MS_PER_DAY = 1e3 * 60 * 60 * 24;
var createDateFromNowWithOffset = (offsetInDays) => {
  const currentDate = /* @__PURE__ */ new Date();
  const offsetInMilliseconds = offsetInDays * MS_PER_DAY;
  const newDate = new Date(currentDate.getTime() + offsetInMilliseconds);
  return newDate;
};

// src/util/fs/fsDelete.ts
import fs, { existsSync } from "fs-extra";
var fsDeleteDirectory = (directoryPath) => __async(void 0, null, function* () {
  if (!existsSync(directoryPath))
    return true;
  yield fs.rm(directoryPath, { recursive: true, force: true });
  return true;
});
var fsDeleteFile = (filePath) => __async(void 0, null, function* () {
  return fs.promises.rm(filePath, { force: true }).then(
    () => true,
    () => true
  );
});

// src/util/fs/fsDownloadFromUrl.ts
import axios from "axios";
import { fileTypeFromBuffer } from "file-type";

// src/util/fs/fsWrite.ts
import { writeFile, ensureDir } from "fs-extra";
var writeToFile = (directory, content, fileName) => __async(void 0, null, function* () {
  yield ensureDir(directory);
  const filePath = `${directory}/${fileName}`;
  yield writeFile(filePath, content);
  return filePath;
});

// src/convert/index.ts
var convert_exports = {};
__export(convert_exports, {
  bytesToMb: () => bytesToMb,
  epochToDate: () => epochToDate
});

// src/convert/bytesToMb.ts
var bytesToMb = (bytes) => Math.round(bytes / 1024 / 1024);

// src/convert/epochToDate.ts
var epochToDate = (epoch) => new Date(Number(epoch) * 1e3);

// src/util/fs/fsDownloadFromUrl.ts
var downloadFileFromUrl = (_0) => __async(void 0, [_0], function* ({
  url,
  fileName,
  directoryPath,
  limit
}) {
  var _a;
  if (!url || !directoryPath) {
    throw new Error("Url and DirectoryPath are required");
  }
  const fileLimit = __spreadValues({
    minBytes: 0,
    maxBytes: 100 * 1024 * 1024
  }, limit);
  const { data, headers } = yield axios.get(url, {
    responseType: "arraybuffer",
    maxBodyLength: fileLimit.maxBytes
  });
  const contentLength = parseInt((_a = headers["content-length"]) != null ? _a : "0", 10);
  if (isNaN(contentLength) || contentLength <= 0 || contentLength > fileLimit.maxBytes || contentLength < fileLimit.minBytes) {
    throw new Error(
      `Media size is invalid. Size should be between ${fileLimit.maxBytes} and ${fileLimit.minBytes} bytes or between ${bytesToMb(
        fileLimit.maxBytes
      )} and ${bytesToMb(fileLimit.minBytes)}`
    );
  }
  const fileType = yield fileTypeFromBuffer(data);
  if (!fileType || !isValidMediaType(fileType.mime)) {
    throw new Error("Invalid media type. Should be image, video, pdf or doc");
  }
  const fileNameString = fileName != null ? fileName : `${Date.now()}-${Math.random()}.${fileType.ext}`;
  const filePath = yield writeToFile(
    directoryPath,
    data,
    fileNameString
  );
  const fileData = {
    path: filePath,
    size: contentLength,
    sizeInMB: `${(contentLength / 1024 / 1024).toFixed(2)} MB`,
    fileType: fileType.mime,
    fileTypeExt: fileType.ext,
    fileName: fileNameString,
    url,
    createdAt: /* @__PURE__ */ new Date()
  };
  return fileData;
});
var isValidMediaType = (mediaType) => {
  return mediaType.startsWith("image/") || mediaType.startsWith("video/") || mediaType.startsWith("application/pdf") || mediaType.startsWith("application/msword") || mediaType.startsWith(
    "application/vnd.openxmlformats-officedocument.wordprocessingml.document"
  );
};

// src/util/fs/fsJSON.ts
import fs2, { writeJson as writeJsonFile } from "fs-extra";
var readJSONFile = (filePath) => __async(void 0, null, function* () {
  const fileContent = yield fs2.readFile(filePath, "utf8");
  try {
    return JSON.parse(fileContent);
  } catch (error) {
    throw error;
  }
});
var writeJsonToFile = (filePath, jsonData, options) => __async(void 0, null, function* () {
  if (typeof filePath !== "string" || filePath.length === 0) {
    throw new Error("Invalid filePath");
  }
  if (jsonData === null || jsonData === void 0) {
    throw new Error("Invalid jsonData");
  }
  let data;
  if (typeof jsonData === "string") {
    try {
      data = JSON.parse(jsonData);
    } catch (err) {
      throw new Error("Invalid jsonData");
    }
  } else {
    data = jsonData;
  }
  try {
    yield writeJsonFile(filePath, data, options);
    return true;
  } catch (error) {
    throw new Error(
      `Failed to write JSON file: ${filePath}, error: ${error.message}`
    );
  }
});

// src/isValid/index.ts
var isValid_exports = {};
__export(isValid_exports, {
  isValidIpAddress: () => isValidIpAddress,
  isValidJson: () => isValidJson,
  isValidUrl: () => isValidUrl
});

// src/isValid/isValidIpAddress.ts
var isValidIpAddress = (ipAddress) => {
  if (typeof ipAddress !== "string") {
    throw new TypeError("ipAddress must be a string");
  }
  const ipAddressRegex = /^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/;
  return ipAddressRegex.test(ipAddress);
};

// src/isValid/isValidJson.ts
var isValidJson = (json) => {
  try {
    if (typeof json !== "string") {
      return false;
    }
    JSON.parse(json);
  } catch (e) {
    return false;
  }
  return true;
};

// src/isValid/isValidUrl.ts
var defaultAllowed = ["https:", "http:"];
var allowedLocalHosts = ["localhost", "127.0.0.1"];
var isValidUrl = (url, allowedProtocols) => {
  var _a;
  try {
    if (typeof url !== "string") {
      throw new TypeError("url must be a string");
    }
    if (url.length === 0)
      return false;
    if (allowedLocalHosts.includes(url))
      return true;
    if (url.includes(".") && !url.includes("://"))
      return isValidUrl(`http://${url}`);
    const fccUrl = new URL(url);
    const mapProtocols = (_a = allowedProtocols == null ? void 0 : allowedProtocols.map((p) => p.endsWith(":") ? p : `${p}:`)) != null ? _a : [];
    const checkProtocols = [...defaultAllowed, ...mapProtocols].map(
      (p) => p.toLowerCase()
    );
    const check = checkProtocols.includes(fccUrl.protocol) || checkProtocols.includes(fccUrl.protocol.toLowerCase());
    if (check)
      return true;
    return false;
  } catch (error) {
    return false;
  }
};
export {
  convert_exports as convert,
  isValid_exports as isValid,
  util_exports as util
};
//# sourceMappingURL=index.mjs.map